pub enum TcpDisconnectReason {
LocalClose,
IoError(Arc<Error>),
HeartbeatTimeout(Arc<Elapsed>),
BadHandshake,
ThreadPanic(Arc<JoinError>),
}Variants
LocalClose
The local stream was closed, so we terminated the connection with the peer as no one is around to process the data.
IoError(Arc<Error>)
The IO raised an error during processing.
HeartbeatTimeout(Arc<Elapsed>)
We failed to receive a heartbeat in the set time frame.
BadHandshake
The peer sent us an invalide node id as the first payload.
ThreadPanic(Arc<JoinError>)
A Tokio task panic.